/**
 * GMyth Library
 *
 * @file gmyth/gmyth_programinfo.c
 * 
 * @brief <p> GMythFileTransfer deals with the file streaming media remote/local
 * transfering to the MythTV frontend.
 *
 * Copyright (C) 2006 INdT - Instituto Nokia de Tecnologia.
 * @author Leonardo Sobral Cunha <leonardo.cunha@indt.org.br>
 *
 *//*
 * 
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 */
 
#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include "gmyth_programinfo.h"

GMythStringList*
gmyth_program_info_to_string_list (GMythProgramInfo *prog, GMythStringList *slist)
{
    g_return_val_if_fail (prog != NULL, NULL);
    g_return_val_if_fail (slist != NULL, NULL);

    gmyth_string_list_append_string (slist, prog->title);
    gmyth_string_list_append_string (slist, prog->subtitle);
    gmyth_string_list_append_string (slist, prog->description);
    gmyth_string_list_append_string (slist, prog->category);
    gmyth_string_list_append_string (slist, prog->chanid);
    gmyth_string_list_append_string (slist, prog->chanstr);
    gmyth_string_list_append_string (slist, prog->chansign);
    gmyth_string_list_append_string (slist, prog->channame);
    gmyth_string_list_append_string (slist, prog->pathname);
    gmyth_string_list_append_int64 (slist, prog->filesize);

    gmyth_string_list_append_int (slist, 0); //DATETIME_TO_LIST(startts)
    gmyth_string_list_append_int (slist, 0); //DATETIME_TO_LIST(endts)
    gmyth_string_list_append_int (slist, prog->duplicate);
    gmyth_string_list_append_int (slist, prog->shareable);
    gmyth_string_list_append_int (slist, prog->findid);
    gmyth_string_list_append_string (slist, prog->hostname);
    gmyth_string_list_append_int (slist, prog->sourceid);
    gmyth_string_list_append_int (slist, prog->cardid);
    gmyth_string_list_append_int (slist, prog->inputid);
    gmyth_string_list_append_int (slist, prog->recpriority);
    gmyth_string_list_append_int (slist, 0 /*prog->recstatus*/);
    gmyth_string_list_append_int (slist, prog->recordid);
    gmyth_string_list_append_int (slist, 0 /*prog->rectype*/);
    gmyth_string_list_append_int (slist, 0 /*prog->dupin*/);
    gmyth_string_list_append_int (slist, 0 /*prog->dupmethod*/);
    gmyth_string_list_append_int (slist, 0); //DATETIME_TO_LIST(recstartts)
    gmyth_string_list_append_int (slist, 0); //DATETIME_TO_LIST(recendts)
    gmyth_string_list_append_int (slist, prog->repeat);
    gmyth_string_list_append_int (slist, prog->programflags);
    gmyth_string_list_append_char_array (slist, "Default"); //prog->(recgroup != "") ? recgroup : "Default")
    gmyth_string_list_append_int (slist, prog->chancommfree);
    gmyth_string_list_append_string (slist, prog->chanOutputFilters);
    gmyth_string_list_append_string (slist, prog->seriesid);
    gmyth_string_list_append_string (slist, prog->programid);
    gmyth_string_list_append_int (slist, 0); //DATETIME_TO_LIST(lastmodified)
    gmyth_string_list_append_int (slist, 0); //FLOAT_TO_LIST(stars)
    gmyth_string_list_append_int (slist, 0); //DATETIME_TO_LIST(QDateTime(originalAirDate))
    gmyth_string_list_append_int (slist, prog->hasAirDate);
    gmyth_string_list_append_char_array (slist, "Default"); //prog->(playgroup != "") ? playgroup : "Default")
    gmyth_string_list_append_int (slist, prog->recpriority2);
   
    return slist;
}

GMythProgramInfo*
gmyth_program_info_from_string_list ()
{
    return NULL;
}
